@@ -7,14 +7,15 @@
 dateBreaks <- function(x, n = 5, min.n = n %/% 2, ...) {
   ## get rid of R check annoyances
 
-
   isDate <- inherits(x, "Date")
   x <- as.POSIXct(x)
-  if (isDate) { # the timezone *does* matter
+  if (isDate) {
+    # the timezone *does* matter
     attr(x, "tzone") <- "GMT"
   }
   zz <- range(x, na.rm = TRUE)
-  if (diff(as.numeric(zz)) == 0) { # one value only
+  if (diff(as.numeric(zz)) == 0) {
+    # one value only
     zz <- zz + c(0, 60)
   }
 
@@ -98,7 +99,9 @@ dateBreaks <- function(x, n = 5, min.n = n %/% 2, ...) {
   ## bump it up if below acceptable threshold
   while (init.n < min.n) {
     init.i <- init.i - 1L
-    if (init.i == 0) stop("range too small for min.n")
+    if (init.i == 0) {
+      stop("range too small for min.n")
+    }
     init.at <- calcSteps(steps[[init.i]])
     init.n <- length(init.at) - 1L
   }
@@ -116,7 +119,8 @@ dateBreaks <- function(x, n = 5, min.n = n %/% 2, ...) {
     list(major = ans, format = s$format)
     #  ans
   }
-  if (init.n == n) { ## perfect
+  if (init.n == n) {
+    ## perfect
     return(makeOutput(init.at, steps[[init.i]]))
   }
   if (init.n > n) {
@@ -142,18 +146,29 @@ dateBreaks <- function(x, n = 5, min.n = n %/% 2, ...) {
 }
 ## utility function, extending the base function of same name
 dateTrunc <-
-  function(x, units = c(
-           "secs", "mins", "hours", "days",
-           "weeks", "months", "years", "decades", "centuries"
-         ),
-         start.on.monday = TRUE) {
+  function(
+    x,
+    units = c(
+      "secs",
+      "mins",
+      "hours",
+      "days",
+      "weeks",
+      "months",
+      "years",
+      "decades",
+      "centuries"
+    ),
+    start.on.monday = TRUE
+  ) {
     x <- as.POSIXlt(x)
     if (units %in% c("secs", "mins", "hours", "days")) {
       return(base::trunc.POSIXt(x, units))
     }
     x <- base::trunc.POSIXt(x, "days")
     if (length(x$sec)) {
-      switch(units,
+      switch(
+        units,
         weeks = {
           x$mday <- x$mday - x$wday
           if (start.on.monday) {
@@ -182,45 +197,61 @@ dateTrunc <-
     x
   }
 
-dateCeil <- function(x, units = c(
-                     "secs", "mins", "hours", "days", "months",
-                     "years"
-                   ), ...) {
+dateCeil <- function(
+  x,
+  units = c(
+    "secs",
+    "mins",
+    "hours",
+    "days",
+    "months",
+    "years"
+  ),
+  ...
+) {
   units <- match.arg(units)
   x <- as.POSIXlt(x)
   isdst <- x$isdst
   if (length(x$sec) > 0 && x != dateTrunc(x, units = units)) {
-    switch(units, secs = {
-      x$sec <- ceiling(x$sec)
-    }, mins = {
-      x$sec <- 0
-      x$min <- x$min + 1
-    }, hours = {
-      x$sec <- 0
-      x$min <- 0
-      x$hour <- x$hour + 1
-    }, days = {
-      x$sec <- 0
-      x$min <- 0
-      x$hour <- 0
-      x$mday <- x$mday + 1
-      isdst <- x$isdst <- -1
-    }, months = {
-      x$sec <- 0
-      x$min <- 0
-      x$hour <- 0
-      x$mday <- 1
-      x$mon <- x$mon + 1
-      isdst <- x$isdst <- -1
-    }, years = {
-      x$sec <- 0
-      x$min <- 0
-      x$hour <- 0
-      x$mday <- 1
-      x$mon <- 0
-      x$year <- x$year + 1
-      isdst <- x$isdst <- -1
-    })
+    switch(
+      units,
+      secs = {
+        x$sec <- ceiling(x$sec)
+      },
+      mins = {
+        x$sec <- 0
+        x$min <- x$min + 1
+      },
+      hours = {
+        x$sec <- 0
+        x$min <- 0
+        x$hour <- x$hour + 1
+      },
+      days = {
+        x$sec <- 0
+        x$min <- 0
+        x$hour <- 0
+        x$mday <- x$mday + 1
+        isdst <- x$isdst <- -1
+      },
+      months = {
+        x$sec <- 0
+        x$min <- 0
+        x$hour <- 0
+        x$mday <- 1
+        x$mon <- x$mon + 1
+        isdst <- x$isdst <- -1
+      },
+      years = {
+        x$sec <- 0
+        x$min <- 0
+        x$hour <- 0
+        x$mday <- 1
+        x$mon <- 0
+        x$year <- x$year + 1
+        isdst <- x$isdst <- -1
+      }
+    )
     x <- as.POSIXlt(as.POSIXct(x))
     if (isdst == -1) {
       x$isdst <- -1
@@ -232,7 +263,9 @@ dateCeil <- function(x, units = c(
 ## not overlu useful yet!
 roundDate <- function(dates, avg.time = "hour", start.date = NULL) {
   TZ <- attr(dates, "tzone")
-  if (is.null(TZ)) TZ <- "GMT" ## as it is on Windows for BST
+  if (is.null(TZ)) {
+    TZ <- "GMT"
+  } ## as it is on Windows for BST
 
   if (!missing(start.date)) {
     dates <- c(as.POSIXct(start.date), dates)
