@@ -94,8 +94,10 @@
 #' @param year Year(s) to import. To import a series of years use, e.g.,
 #'   `2000:2020`. To import several specific years use `year = c(2000, 2010,
 #'   2020)`.
-#' @param source The network to which the `site`(s) belong, defaulting to
-#'   `"aurn"`. Providing a single network will attempt to import all of the
+#' @param source The network to which the `site`(s) belong. The default, `NULL`,
+#'   allows [importUKAQ()] to guess the correct `source`, preferring national
+#'   networks over locally managed networks. Alternatively, users can define a
+#'   `source`. Providing a single network will attempt to import all of the
 #'   given `site`s from the provided network. Alternatively, a vector of sources
 #'   can be provided of the same length as `site` to indicate which network each
 #'   `site` individually belongs. Available networks include:
@@ -119,19 +121,24 @@
 #'   more details of how the index is defined. Note that this `data_type` is not
 #'   available for locally managed monitoring networks.
 #' @param pollutant Pollutants to import. If omitted will import all pollutants
-#'   from a site. To import only NOx and NO2 for example use \code{pollutant =
-#'   c("nox", "no2")}. Pollutant names can be upper or lower case.
+#'   from a site. To import only NOx and NO2 for example use `pollutant =
+#'   c("nox", "no2")`. Pollutant names can be upper or lower case.
 #' @param hc Include hydrocarbon measurements in the imported data? Defaults to
 #'   `FALSE` as most users will not be interested in using hydrocarbon data.
-#' @param meta Append the site type, latitude and longitude of each selected
-#'   `site`? Defaults to `FALSE`.
+#' @param meta Append metadata columns to data for each selected `site`?
+#'   Defaults to `FALSE`. Columns are defined using `meta_columns`.
+#' @param meta_columns The specific columns to append when `meta = TRUE`.
+#'   Defaults to site type, latitude and longitude. Can be any of `"site_type"`,
+#'   `"latitude"`, `"longitude"`, `"zone"`, `"agglomeration"`, and
+#'   `"local_authority"` (as well as `"provider"` for locally managed data). See
+#'   [importMeta()] for more complete information.
 #' @param meteo Append modelled meteorological data, if available? Defaults to
 #'   `TRUE`, which will return wind speed (`ws`), wind direction (`wd`) and
 #'   ambient temperature (`air_temp`). The variables are calculated from using
 #'   the WRF model run by Ricardo Energy & Environment and are available for
 #'   most but not all networks. Setting `meteo = FALSE` is useful if you have
-#'   other meteorological data to use in preference, for example from
-#'   the `worldmet` package.
+#'   other meteorological data to use in preference, for example from the
+#'   `worldmet` package.
 #' @param ratified Append `qc` column(s) to hourly data indicating whether each
 #'   species was ratified (i.e., quality-checked)?  Defaults to `FALSE`.
 #' @param to_narrow Return the data in a "narrow"/"long"/"tidy" format? By
@@ -181,18 +188,21 @@
 #' )
 #' }
 importUKAQ <-
-  function(site = "my1",
-           year = 2022,
-           source = "aurn",
-           data_type = "hourly",
-           pollutant = "all",
-           hc = FALSE,
-           meta = FALSE,
-           meteo = TRUE,
-           ratified = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "my1",
+    year = 2022,
+    source = NULL,
+    data_type = "hourly",
+    pollutant = "all",
+    hc = FALSE,
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    meteo = TRUE,
+    ratified = FALSE,
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     # warn if source == "local"
     if ("local" %in% source) {
       cli::cli_warn(
@@ -205,13 +215,47 @@ importUKAQ <-
       )
     }
 
+    # guess sources
+    if (is.null(source)) {
+      if (data_type %in% c("annual", "monthly", "daqi") & missing(site)) {
+        cli::cli_abort(
+          "Please provide a {.field source} when {.field data_type} is '{data_type}'."
+        )
+      }
+      source <- guess_source(site)
+    }
+
+    # check correct "meta_columns" are passed
+    if (meta) {
+      meta_opts <- c(
+        "site_type",
+        "latitude",
+        "longitude",
+        "zone",
+        "agglomeration",
+        "local_authority"
+      )
+
+      if ("local" %in% source) {
+        meta_opts <- append(meta_opts, "provider")
+      }
+
+      meta_columns <-
+        rlang::arg_match(
+          meta_columns,
+          meta_opts,
+          multiple = TRUE
+        )
+    }
+
     # obtain correct URL info for the source
     url_domain <- dplyr::case_match(
       source,
       "aurn" ~ "https://uk-air.defra.gov.uk/openair/R_data/",
       "aqe" ~ "https://airqualityengland.co.uk/assets/openair/R_data/",
       "saqn" ~ "https://www.scottishairquality.scot/openair/R_data/",
-      "waqn" ~ "https://airquality.gov.wales/sites/default/files/openair/R_data/",
+      "waqn" ~
+        "https://airquality.gov.wales/sites/default/files/openair/R_data/",
       "ni" ~ "https://www.airqualityni.co.uk/openair/R_data/",
       "local" ~ "https://uk-air.defra.gov.uk/openair/LMAM/R_data/"
     )
@@ -230,16 +274,21 @@ importUKAQ <-
     allowed_types <- c(
       "hourly",
       "daily",
-      "15min",
       "monthly",
       "annual",
       "daqi",
+      "15min",
       "15_min",
       "24_hour",
       "8_hour",
       "daily_max_8"
     )
 
+    # handle 15_min for back-compatibility reasons
+    if (data_type == "15_min") {
+      data_type <- "15min"
+    }
+
     if (!tolower(data_type) %in% allowed_types) {
       cli::cli_warn(
         c(
@@ -264,7 +313,7 @@ importUKAQ <-
 
       # import statistics
       aq_data <- purrr::pmap(
-        list(files, year, source),
+        tidyr::crossing(tidyr::nesting(files, source), year),
         readSummaryData,
         data_type = data_type,
         to_narrow = to_narrow,
@@ -277,7 +326,9 @@ importUKAQ <-
     # Import pre-calculated DAQI?
     if (data_type == "daqi") {
       if ("local" %in% source) {
-        cli::cli_abort(c("!" = "{.arg data_type} 'DAQI' is not available for locally managed networks"))
+        cli::cli_abort(c(
+          "!" = "{.arg data_type} 'DAQI' is not available for locally managed networks"
+        ))
       }
       if (missing(site)) {
         site <- "all"
@@ -290,11 +341,23 @@ importUKAQ <-
 
       # import DAQI
       aq_data <-
-        purrr::pmap(list(files, year, source),
+        purrr::pmap(
+          tidyr::crossing(tidyr::nesting(files, source), year),
           readDAQI,
           .progress = ifelse(progress, "Importing DAQI", FALSE)
         ) %>%
-        purrr::list_rbind()
+        purrr::list_rbind() %>%
+        dplyr::tibble() %>%
+        dplyr::mutate(
+          band = dplyr::case_when(
+            .data$poll_index %in% 1:3 ~ "Low",
+            .data$poll_index %in% 4:6 ~ "Moderate",
+            .data$poll_index %in% 7:9 ~ "High",
+            .data$poll_index == 10 ~ "Very High"
+          ),
+          band = factor(.data$band, c("Low", "Moderate", "High", "Very High")),
+          .after = "poll_index"
+        )
     }
 
     # Import any other stat
@@ -303,7 +366,9 @@ importUKAQ <-
       if (length(source) == 1) {
         source <- rep(source, times = length(site))
       } else if (length(source) != length(site)) {
-        cli::cli_abort("Length of {.arg source} ({length(source)}) not equal to 1 or length of {.arg site} ({length(site)}).")
+        cli::cli_abort(
+          "Length of {.arg source} ({length(source)}) not equal to 1 or length of {.arg site} ({length(site)})."
+        )
       }
 
       # deal with additional paths needed for local data
@@ -321,7 +386,7 @@ importUKAQ <-
             source = source,
             url_data = url_domain
           ) %>%
-          merge(pcodes) %>%
+          dplyr::left_join(pcodes, by = "code") %>%
           tidyr::crossing(year = year)
       } else {
         site_info <-
@@ -337,24 +402,28 @@ importUKAQ <-
       aq_data <-
         purrr::pmap(
           .l = site_info,
-          .f = purrr::possibly(~ readUKAQData(
-            site = ..1,
-            lmam_subfolder = ..4,
-            year = ..5,
-            data_type,
-            pollutant = pollutant,
-            hc = hc,
-            to_narrow = to_narrow,
-            source = ..2,
-            url_data = ..3,
-            verbose = verbose
-          ), quiet = !verbose),
+          .f = purrr::possibly(
+            ~ readUKAQData(
+              site = ..1,
+              lmam_subfolder = ..4,
+              year = ..5,
+              data_type,
+              pollutant = pollutant,
+              hc = hc,
+              to_narrow = to_narrow,
+              source = ..2,
+              url_data = ..3,
+              verbose = verbose
+            ),
+            quiet = !verbose
+          ),
           .progress = ifelse(progress, "Importing AQ Data", FALSE)
         ) %>%
         purrr::list_rbind()
 
       if (nrow(aq_data) == 0) {
-        cli::cli_abort("No data returned. Check {.arg site}, {.arg year} and {.arg source}.",
+        cli::cli_abort(
+          "No data returned. Check {.arg site}, {.arg year} and {.arg source}.",
           call = NULL
         )
       }
@@ -389,7 +458,8 @@ importUKAQ <-
 
     # add meta data?
     if (meta) {
-      aq_data <- add_meta(source = source, aq_data)
+      aq_data <-
+        add_meta(source = source, columns = meta_columns, aq_data)
     }
 
     # arrange output by source
@@ -422,17 +492,20 @@ importUKAQ <-
 #' @family import functions
 #' @export
 importAURN <-
-  function(site = "my1",
-           year = 2009,
-           data_type = "hourly",
-           pollutant = "all",
-           hc = FALSE,
-           meta = FALSE,
-           meteo = TRUE,
-           ratified = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "my1",
+    year = 2009,
+    data_type = "hourly",
+    pollutant = "all",
+    hc = FALSE,
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    meteo = TRUE,
+    ratified = FALSE,
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     if (missing(site) & data_type %in% c("annual", "monthly", "daqi")) {
       site <- "all"
     }
@@ -444,6 +517,7 @@ importAURN <-
       pollutant = pollutant,
       hc = hc,
       meta = meta,
+      meta_columns = meta_columns,
       meteo = meteo,
       ratified = ratified,
       to_narrow = to_narrow,
@@ -457,16 +531,19 @@ importAURN <-
 #' @order 2
 #' @export
 importAQE <-
-  function(site = "yk13",
-           year = 2018,
-           data_type = "hourly",
-           pollutant = "all",
-           meta = FALSE,
-           meteo = TRUE,
-           ratified = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "yk13",
+    year = 2018,
+    data_type = "hourly",
+    pollutant = "all",
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    meteo = TRUE,
+    ratified = FALSE,
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     if (missing(site) & data_type %in% c("annual", "monthly", "daqi")) {
       site <- "all"
     }
@@ -477,6 +554,7 @@ importAQE <-
       data_type = data_type,
       pollutant = pollutant,
       meta = meta,
+      meta_columns = meta_columns,
       meteo = meteo,
       ratified = ratified,
       to_narrow = to_narrow,
@@ -490,16 +568,19 @@ importAQE <-
 #' @order 3
 #' @export
 importSAQN <-
-  function(site = "gla4",
-           year = 2009,
-           data_type = "hourly",
-           pollutant = "all",
-           meta = FALSE,
-           meteo = TRUE,
-           ratified = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "gla4",
+    year = 2009,
+    data_type = "hourly",
+    pollutant = "all",
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    meteo = TRUE,
+    ratified = FALSE,
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     if (missing(site) & data_type %in% c("annual", "monthly", "daqi")) {
       site <- "all"
     }
@@ -510,6 +591,7 @@ importSAQN <-
       data_type = data_type,
       pollutant = pollutant,
       meta = meta,
+      meta_columns = meta_columns,
       meteo = meteo,
       ratified = ratified,
       to_narrow = to_narrow,
@@ -523,16 +605,19 @@ importSAQN <-
 #' @order 4
 #' @export
 importWAQN <-
-  function(site = "card",
-           year = 2018,
-           data_type = "hourly",
-           pollutant = "all",
-           meta = FALSE,
-           meteo = TRUE,
-           ratified = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "card",
+    year = 2018,
+    data_type = "hourly",
+    pollutant = "all",
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    meteo = TRUE,
+    ratified = FALSE,
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     if (missing(site) & data_type %in% c("annual", "monthly", "daqi")) {
       site <- "all"
     }
@@ -543,6 +628,7 @@ importWAQN <-
       data_type = data_type,
       pollutant = pollutant,
       meta = meta,
+      meta_columns = meta_columns,
       meteo = meteo,
       ratified = ratified,
       to_narrow = to_narrow,
@@ -556,16 +642,19 @@ importWAQN <-
 #' @order 5
 #' @export
 importNI <-
-  function(site = "bel0",
-           year = 2018,
-           data_type = "hourly",
-           pollutant = "all",
-           meta = FALSE,
-           meteo = TRUE,
-           ratified = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "bel0",
+    year = 2018,
+    data_type = "hourly",
+    pollutant = "all",
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    meteo = TRUE,
+    ratified = FALSE,
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     if (missing(site) & data_type %in% c("annual", "monthly", "daqi")) {
       site <- "all"
     }
@@ -576,6 +665,7 @@ importNI <-
       data_type = data_type,
       pollutant = pollutant,
       meta = meta,
+      meta_columns = meta_columns,
       meteo = meteo,
       ratified = ratified,
       to_narrow = to_narrow,
@@ -589,14 +679,17 @@ importNI <-
 #' @order 6
 #' @export
 importLocal <-
-  function(site = "ad1",
-           year = 2018,
-           data_type = "hourly",
-           pollutant = "all",
-           meta = FALSE,
-           to_narrow = FALSE,
-           verbose = FALSE,
-           progress = TRUE) {
+  function(
+    site = "ad1",
+    year = 2018,
+    data_type = "hourly",
+    pollutant = "all",
+    meta = FALSE,
+    meta_columns = c("site_type", "latitude", "longitude"),
+    to_narrow = FALSE,
+    verbose = FALSE,
+    progress = TRUE
+  ) {
     if (missing(site) & data_type %in% c("annual", "monthly", "daqi")) {
       site <- "all"
     }
@@ -607,6 +700,7 @@ importLocal <-
       data_type = data_type,
       pollutant = pollutant,
       meta = meta,
+      meta_columns = meta_columns,
       meteo = TRUE,
       ratified = FALSE,
       to_narrow = to_narrow,
